@@ -1,5 +1,6 @@
 import os
 import typing
+import time
 
 from . import Colours
 from .Check import Check
@@ -41,12 +42,13 @@ class Display:
         cleanOptions = {}
         for option in options:
             if isinstance(options.get(option), tuple):
-                newOptions = (options.get(option)[0], ) + \
-                    (options.get(option)[1].replace(" ", "_"), ) + \
-                    options.get(option)[2:]
+                newOptions = (
+                    (options.get(option)[0],)
+                    + (options.get(option)[1].replace(" ", "_"),)
+                    + options.get(option)[2:]
+                )
 
-                cleanOptions.update(
-                    {int(option): newOptions})
+                cleanOptions.update({int(option): newOptions})
             else:
                 print(
                     f"{option} with data {options.get(option)} has an invalid data structure"
@@ -64,8 +66,7 @@ class Display:
         if index is None:
             index = len(self.options)
 
-        newOptions = (option[0], ) + \
-            (option[1].replace(" ", "_"), ) + option[2:]
+        newOptions = (option[0],) + (option[1].replace(" ", "_"),) + option[2:]
         self.options.update({index: newOptions})
 
     def RemoveOption(self, index: int):
@@ -94,17 +95,25 @@ class Display:
         """Remove all of the options in the list"""
         self.options = {}
 
-    def ShowHeader(self, *, text: str = "Display.py"):
+    def ShowHeader(self, *, text: str = "Display.py", typewriter: bool = False, pace: int = 100):
         """Print out a header message
 
         Args:
             text: (str, option) The text to display. Deafults to "Display.py".
+            typewritter: (str, optional): Shows the text letter by letter. Defaults to False.
+            pace: (int, optional): Words per second to show using typewritter effect.Defaults to 100
         """
-        print(
-            f"""{Colours.c('g')}{'-' * os.get_terminal_size().columns}{Colours.c()}
-{text}
-{Colours.c('g')}{'-' * os.get_terminal_size().columns}{Colours.c()}"""
-        )
+        print(f"{Colours.c('g')}{'-' * os.get_terminal_size().columns}{Colours.c()}")
+
+        if typewriter:
+            for i in text:
+                print(i, end="", flush=True)
+                time.sleep(pace * 0.001)
+            print()
+        else:
+            print(text)
+
+        print(f"{Colours.c('g')}{'-' * os.get_terminal_size().columns}{Colours.c()}")
 
         self.__storedText = text
 
@@ -258,7 +267,6 @@ W: Up, A: Left, S: Down, D: Right, Q: Quit, Enter: Select"""
                     self.gridData[self.cursorPosition[1]
                                   ][self.cursorPosition[0]]
                 )
-                print(itemInfo)
 
                 if len(itemInfo) > 2:
                     return itemInfo[0](itemInfo[1:])
